# ncurses 5.9 - patch 20130316 - Thomas E. Dickey
#
# ------------------------------------------------------------------------------
#
# Ncurses 5.9 is at
# 	ftp.gnu.org:/pub/gnu
#
# Patches for ncurses 5.9 are in the subdirectory
# 	ftp://invisible-island.net/ncurses/5.9
#
# ------------------------------------------------------------------------------
# ftp://invisible-island.net/ncurses/5.9/ncurses-5.9-20130316.patch.gz
# patch by Thomas E. Dickey <dickey@invisible-island.net>
# created  Sun Mar 17 01:23:04 UTC 2013
# ------------------------------------------------------------------------------
# NEWS                     |   18 +++++++++-
# aclocal.m4               |   35 ++++++++++++++++++--
# c++/Makefile.in          |   37 ++-------------------
# c++/modules              |    5 +-
# configure                |   78 ++++++++++++++++++++++++++++++++++-----------
# configure.in             |   15 +++++++-
# dist.mk                  |    4 +-
# misc/gen-pkgconfig.in    |   12 +++---
# misc/terminfo.src        |   22 ++++++++----
# mk-1st.awk               |   69 ++++++++++++++++++++++++++++-----------
# ncurses/base/lib_addch.c |    4 +-
# package/debian/changelog |    4 +-
# package/ncurses.spec     |    2 -
# progs/dump_entry.c       |   24 +++++++++----
# progs/tic.c              |    4 +-
# 15 files changed, 225 insertions(+), 108 deletions(-)
# ------------------------------------------------------------------------------
Index: NEWS
Prereq:  1.2030 
--- ncurses-5.9-20130309+/NEWS	2013-03-09 22:42:05.000000000 +0000
+++ ncurses-5.9-20130316/NEWS	2013-03-17 01:01:39.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: NEWS,v 1.2030 2013/03/09 22:42:05 tom Exp $
+-- $Id: NEWS,v 1.2035 2013/03/17 01:01:39 tom Exp $
 -------------------------------------------------------------------------------
 
 This is a log of changes that ncurses has gone through since Zeyd started
@@ -45,6 +45,22 @@
 Changes through 1.9.9e did not credit all contributions;
 it is not possible to add this information.
 
+20130316
+	+ additional fix for tic.c, to allocate missing buffer space.
+	+ eliminate configure-script warnings for gen-pkgconfig.in
+	+ correct typo in sgr string for sun-color,
+	  add bold for consistency with sgr,
+	  change smso for consistency with sgr -TD
+	+ correct typo in sgr string for terminator -TD
+	+ add blink to the attributes masked by ncv in linux-16color (report
+	  by Benjamin Sittler)
+	+ improve warning message from post-load checking for missing "%?"
+	  operator by tic/infocmp by showing the entry name and capability.
+	+ minor formatting improvement to tic/infocmp -f option to ensure
+	  line split after "%;".
+	+ amend scripting for --with-cxx-shared option to handle the debug
+	  library "libncurses++_g.a" (report by Sven Joachim).
+
 20130309
 	+ amend change to toe.c for reading from /dev/zero, to ensure that
 	  there is a buffer for the temporary filename (cf: 20120324).
Index: aclocal.m4
Prereq:  1.654 
--- ncurses-5.9-20130309+/aclocal.m4	2013-03-10 00:23:09.000000000 +0000
+++ ncurses-5.9-20130316/aclocal.m4	2013-03-12 13:40:56.000000000 +0000
@@ -28,7 +28,7 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: aclocal.m4,v 1.654 2013/03/10 00:23:09 tom Exp $
+dnl $Id: aclocal.m4,v 1.658 2013/03/12 13:40:56 tom Exp $
 dnl Macros used in NCURSES auto-configuration script.
 dnl
 dnl These macros are maintained separately from NCURSES.  The copyright on
@@ -3232,7 +3232,28 @@
 
 		if test $cf_dir = c++; then
 			if test "x$with_shared_cxx" != xyes; then
-				Libs_To_Make='../lib/$(LIBNAME)'
+				cf_list=
+				for cf_item in $Libs_To_Make
+				do
+					case $cf_item in
+					*.a)
+						;;
+					*)
+						cf_item=`echo "$cf_item" | sed -e 's/\.so.*/.a/'`
+						;;
+					esac
+					for cf_test in $cf_list
+					do
+						if test "$cf_test" = "$cf_item"
+						then
+							cf_LIST_MODELS=`echo "$cf_LIST_MODELS" | sed -e 's/normal//'`
+							cf_item=
+							break
+						fi
+					done
+					test -n "$cf_item" && cf_list="$cf_list $cf_item"
+				done
+				Libs_To_Make="$cf_list"
 			fi
 		fi
 
@@ -3256,7 +3277,15 @@
 
 			CXX_MODEL=$cf_ITEM
 			if test "$CXX_MODEL" = SHARED; then
-				test "x$with_shared_cxx" = xno && CXX_MODEL=NORMAL
+				case $cf_cv_shlib_version in #(vi
+				cygdll|mingw) #(vi
+					test "x$with_shared_cxx" = xno && CF_VERBOSE(overriding CXX_MODEL to SHARED)
+					with_shared_cxx=yes
+					;;
+				*)
+					test "x$with_shared_cxx" = xno && CXX_MODEL=NORMAL
+					;;
+				esac
 			fi
 
 			CF_LIB_SUFFIX($cf_item,cf_suffix,cf_depsuf)
Index: c++/Makefile.in
Prereq:  1.97 
--- ncurses-5.9-20130309+/c++/Makefile.in	2013-03-09 21:22:49.000000000 +0000
+++ ncurses-5.9-20130316/c++/Makefile.in	2013-03-13 09:45:11.000000000 +0000
@@ -1,4 +1,4 @@
-# $Id: Makefile.in,v 1.97 2013/03/09 21:22:49 tom Exp $
+# $Id: Makefile.in,v 1.101 2013/03/13 09:45:11 tom Exp $
 ##############################################################################
 # Copyright (c) 1998-2012,2013 Free Software Foundation, Inc.                #
 #                                                                            #
@@ -153,33 +153,12 @@
 tags:
 	$(CTAGS) *.[h] *.cc
 
-# Build a conventional library for installing, since a shared library would
-# pull in all of the ncurses libraries (panel, menu, form, ncurses) as direct
-# dependencies.
-LIB_OBJS = \
-	$(MODEL)/cursesf$o \
-	$(MODEL)/cursesm$o \
-	$(MODEL)/cursesw$o \
-	$(MODEL)/cursespad$o \
-	$(MODEL)/cursesp$o \
-	$(MODEL)/cursslk$o \
-	$(MODEL)/cursesapp$o \
-	$(MODEL)/cursesmain$o
-
-../lib/$(LIBNAME_NORMAL) : $(LIB_OBJS)
-	$(CXX_AR) $(CXX_ARFLAGS) $@ $?
-	$(RANLIB) $@
-
-../lib/$(LIBNAME_LIBTOOL) : $(LIB_OBJS)
-	cd ../lib && $(LIBTOOL_LINK) $(CXX) $(CXXFLAGS) \
-		-o $(LIBNAME) $(LIB_OBJS:$o=.lo) \
-		-rpath $(INSTALL_PREFIX)$(libdir) \
-		$(LIBTOOL_VERSION) $(NCURSES_MAJOR):$(NCURSES_MINOR) $(LT_UNDEF) $(LDFLAGS_LIBTOOL) $(SHLIB_LIST)
-
 OBJS_DEMO = $(MODEL)/demo$o
 
 $(MODEL)/demo$o : $(srcdir)/demo.cc \
 	$(cursesf_h) $(cursesm_h) $(cursesapp_h)
+	@echo 'compiling demo (obj_s)'
+	@$(LIBTOOL_COMPILE) $(CXX) $(CFLAGS_DEFAULT) -c $(srcdir)/demo.cc -o $@
 
 demo$x:	$(OBJS_DEMO) \
 	$(LIBRARIES)  \
@@ -193,21 +172,13 @@
 $(DESTDIR)$(libdir) :
 	mkdir -p $@
 
-install \
-install.libs:: $(LIBRARIES) $(DESTDIR)$(libdir)
-	$(LIBTOOL_INSTALL) $(INSTALL_LIB) $(LIBRARIES) $(DESTDIR)$(libdir)/$(LIBNAME)
-
-uninstall \
-uninstall.libs::
-	-$(LIBTOOL_UNINSTALL) rm -f $(DESTDIR)$(libdir)/$(LIBNAME)
-
 mostlyclean ::
 	-rm -f core tags TAGS *~ *.bak *.i *.ii *.ln *.atac trace
 
 clean :: mostlyclean
 	-sh -c "if test -n '$x' ; then $(MAKE) clean x=''; fi"
 	-rm -rf $(MODEL)/SunWS_cache
-	-$(LIBTOOL_CLEAN) rm -f demo$x $(AUTO_SRC) $(LIBRARIES) $(LIB_OBJS) $(OBJS_DEMO)
+	-$(LIBTOOL_CLEAN) rm -f demo$x $(AUTO_SRC) $(LIBRARIES) $(OBJS_DEMO)
 	-rm -rf .libs
 
 distclean :: clean
Index: c++/modules
Prereq:  1.7 
--- ncurses-5.9-20130309+/c++/modules	2006-12-24 00:53:08.000000000 +0000
+++ ncurses-5.9-20130316/c++/modules	2013-03-13 09:57:40.000000000 +0000
@@ -1,5 +1,5 @@
 # Program modules
-# $Id: modules,v 1.7 2006/12/24 00:53:08 tom Exp $
+# $Id: modules,v 1.9 2013/03/13 09:57:40 tom Exp $
 ##############################################################################
 # Copyright (c) 1998,2006 Free Software Foundation, Inc.                     #
 #                                                                            #
@@ -34,12 +34,11 @@
 @ base
 cursesf		c++		$(srcdir)	$(cursesf_h) $(cursesapp_h)
 cursesm		c++		$(srcdir)	$(cursesm_h) $(cursesapp_h)
-cursesp		c++		$(srcdir)	$(cursesp_h)
 cursesw		c++		$(srcdir)	$(cursesw_h)
 cursespad	c++		$(srcdir)	$(cursesw_h)
+cursesp		c++		$(srcdir)	$(cursesp_h)
 cursslk		c++		$(srcdir)	$(cursslk_h) $(cursesapp_h)
 cursesapp	c++		$(srcdir)	$(cursesapp_h)
 cursesmain	c++		$(srcdir)	$(cursesapp_h)
-demo		c++		$(srcdir)	$(cursesf_h) $(cursesm_h) $(cursesapp_h)
 
 # vile:makemode
Index: configure
--- ncurses-5.9-20130309+/configure	2013-03-10 00:13:34.000000000 +0000
+++ ncurses-5.9-20130316/configure	2013-03-16 23:35:13.000000000 +0000
@@ -1,5 +1,5 @@
 #! /bin/sh
-# From configure.in Revision: 1.563 .
+# From configure.in Revision: 1.564 .
 # Guess values for system-dependent variables and create Makefiles.
 # Generated by Autoconf 2.52.20121002.
 #
@@ -20516,6 +20516,12 @@
 
 ADAHTML_DIR=../../doc/html/ada
 
+# these could be configurable, but are not currently
+PANEL_NAME=panel
+MENU_NAME=menu
+FORM_NAME=form
+CXX_NAME=ncurses++
+
 SUB_SCRIPTS=
 
 ac_config_files="$ac_config_files include/MKterm.h.awk include/curses.head:include/curses.h.in include/ncurses_dll.h include/termcap.h include/unctrl.h $SUB_SCRIPTS $SUB_MAKEFILES Makefile"
@@ -20599,7 +20605,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:20602: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:20608: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -20775,7 +20781,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:20778: error: ambiguous option: $1
+    { { echo "$as_me:20784: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -20794,7 +20800,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:20797: error: unrecognized option: $1
+  -*) { { echo "$as_me:20803: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -20904,7 +20910,7 @@
   "Makefile" ) CONFIG_FILES="$CONFIG_FILES Makefile" ;;
   "default" ) CONFIG_COMMANDS="$CONFIG_COMMANDS default" ;;
   "include/ncurses_cfg.h" ) CONFIG_HEADERS="$CONFIG_HEADERS include/ncurses_cfg.h:include/ncurses_cfg.hin" ;;
-  *) { { echo "$as_me:20907: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:20913: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -21211,6 +21217,10 @@
 s,@TIC_PATH@,$TIC_PATH,;t t
 s,@MAKE_TESTS@,$MAKE_TESTS,;t t
 s,@ADAHTML_DIR@,$ADAHTML_DIR,;t t
+s,@PANEL_NAME@,$PANEL_NAME,;t t
+s,@MENU_NAME@,$MENU_NAME,;t t
+s,@FORM_NAME@,$FORM_NAME,;t t
+s,@CXX_NAME@,$CXX_NAME,;t t
 CEOF
 
 EOF
@@ -21325,7 +21335,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:21328: creating $ac_file" >&5
+    { echo "$as_me:21338: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -21343,7 +21353,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:21346: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:21356: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -21356,7 +21366,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:21359: error: cannot find input file: $f" >&5
+           { { echo "$as_me:21369: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -21372,7 +21382,7 @@
       if test -n "$ac_seen"; then
         ac_used=`grep '@datarootdir@' $ac_item`
         if test -z "$ac_used"; then
-          { echo "$as_me:21375: WARNING: datarootdir was used implicitly but not set:
+          { echo "$as_me:21385: WARNING: datarootdir was used implicitly but not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: datarootdir was used implicitly but not set:
 $ac_seen" >&2;}
@@ -21381,7 +21391,7 @@
       fi
       ac_seen=`grep '${datarootdir}' $ac_item`
       if test -n "$ac_seen"; then
-        { echo "$as_me:21384: WARNING: datarootdir was used explicitly but not set:
+        { echo "$as_me:21394: WARNING: datarootdir was used explicitly but not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: datarootdir was used explicitly but not set:
 $ac_seen" >&2;}
@@ -21418,7 +21428,7 @@
             ac_init=`egrep '[ 	]*'$ac_name'[ 	]*=' $ac_file`
             if test -z "$ac_init"; then
               ac_seen=`echo "$ac_seen" |sed -e 's,^,'$ac_file':,'`
-              { echo "$as_me:21421: WARNING: Variable $ac_name is used but was not set:
+              { echo "$as_me:21431: WARNING: Variable $ac_name is used but was not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: Variable $ac_name is used but was not set:
 $ac_seen" >&2;}
@@ -21429,7 +21439,7 @@
     egrep -n '@[A-Z_][A-Z_0-9]+@' $ac_file >>$tmp/out
     if test -s $tmp/out; then
       ac_seen=`sed -e 's,^,'$ac_file':,' < $tmp/out`
-      { echo "$as_me:21432: WARNING: Some variables may not be substituted:
+      { echo "$as_me:21442: WARNING: Some variables may not be substituted:
 $ac_seen" >&5
 echo "$as_me: WARNING: Some variables may not be substituted:
 $ac_seen" >&2;}
@@ -21478,7 +21488,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:21481: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:21491: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -21489,7 +21499,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:21492: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:21502: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -21502,7 +21512,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:21505: error: cannot find input file: $f" >&5
+           { { echo "$as_me:21515: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -21560,7 +21570,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:21563: $ac_file is unchanged" >&5
+      { echo "$as_me:21573: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
@@ -21821,7 +21831,28 @@
 
 		if test $cf_dir = c++; then
 			if test "x$with_shared_cxx" != xyes; then
-				Libs_To_Make='../lib/$(LIBNAME)'
+				cf_list=
+				for cf_item in $Libs_To_Make
+				do
+					case $cf_item in
+					*.a)
+						;;
+					*)
+						cf_item=`echo "$cf_item" | sed -e 's/\.so.*/.a/'`
+						;;
+					esac
+					for cf_test in $cf_list
+					do
+						if test "$cf_test" = "$cf_item"
+						then
+							cf_LIST_MODELS=`echo "$cf_LIST_MODELS" | sed -e 's/normal//'`
+							cf_item=
+							break
+						fi
+					done
+					test -n "$cf_item" && cf_list="$cf_list $cf_item"
+				done
+				Libs_To_Make="$cf_list"
 			fi
 		fi
 
@@ -21846,7 +21877,18 @@
 
 			CXX_MODEL=$cf_ITEM
 			if test "$CXX_MODEL" = SHARED; then
-				test "x$with_shared_cxx" = xno && CXX_MODEL=NORMAL
+				case $cf_cv_shlib_version in #(vi
+				cygdll|mingw) #(vi
+					test "x$with_shared_cxx" = xno && test -n "$verbose" && echo "	overriding CXX_MODEL to SHARED" 1>&6
+
+echo "${as_me:-configure}:21884: testing overriding CXX_MODEL to SHARED ..." 1>&5
+
+					with_shared_cxx=yes
+					;;
+				*)
+					test "x$with_shared_cxx" = xno && CXX_MODEL=NORMAL
+					;;
+				esac
 			fi
 
 	case $cf_item in #(vi
Index: configure.in
Prereq:  1.563 
--- ncurses-5.9-20130309+/configure.in	2013-03-09 21:15:51.000000000 +0000
+++ ncurses-5.9-20130316/configure.in	2013-03-16 23:32:24.000000000 +0000
@@ -28,14 +28,14 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: configure.in,v 1.563 2013/03/09 21:15:51 tom Exp $
+dnl $Id: configure.in,v 1.564 2013/03/16 23:32:24 tom Exp $
 dnl Process this file with autoconf to produce a configure script.
 dnl
 dnl See http://invisible-island.net/autoconf/ for additional information.
 dnl
 dnl ---------------------------------------------------------------------------
 AC_PREREQ(2.52.20030208)
-AC_REVISION($Revision: 1.563 $)
+AC_REVISION($Revision: 1.564 $)
 AC_INIT(ncurses/base/lib_initscr.c)
 AC_CONFIG_HEADER(include/ncurses_cfg.h:include/ncurses_cfg.hin)
 
@@ -1904,6 +1904,17 @@
 ADAHTML_DIR=../../doc/html/ada
 AC_SUBST(ADAHTML_DIR)
 
+# these could be configurable, but are not currently
+PANEL_NAME=panel
+MENU_NAME=menu
+FORM_NAME=form
+CXX_NAME=ncurses++
+
+AC_SUBST(PANEL_NAME)
+AC_SUBST(MENU_NAME)
+AC_SUBST(FORM_NAME)
+AC_SUBST(CXX_NAME)
+
 SUB_SCRIPTS=
 
 AC_OUTPUT( \
Index: dist.mk
Prereq:  1.917 
--- ncurses-5.9-20130309+/dist.mk	2013-03-09 15:56:30.000000000 +0000
+++ ncurses-5.9-20130316/dist.mk	2013-03-16 16:00:27.000000000 +0000
@@ -25,7 +25,7 @@
 # use or other dealings in this Software without prior written               #
 # authorization.                                                             #
 ##############################################################################
-# $Id: dist.mk,v 1.917 2013/03/09 15:56:30 tom Exp $
+# $Id: dist.mk,v 1.919 2013/03/16 16:00:27 tom Exp $
 # Makefile for creating ncurses distributions.
 #
 # This only needs to be used directly as a makefile by developers, but
@@ -37,7 +37,7 @@
 # These define the major/minor/patch versions of ncurses.
 NCURSES_MAJOR = 5
 NCURSES_MINOR = 9
-NCURSES_PATCH = 20130309
+NCURSES_PATCH = 20130316
 
 # We don't append the patch to the version, since this only applies to releases
 VERSION = $(NCURSES_MAJOR).$(NCURSES_MINOR)
Index: misc/gen-pkgconfig.in
Prereq:  1.14 
--- ncurses-5.9-20130309+/misc/gen-pkgconfig.in	2012-01-01 01:48:23.000000000 +0000
+++ ncurses-5.9-20130316/misc/gen-pkgconfig.in	2013-03-16 23:33:34.000000000 +0000
@@ -1,7 +1,7 @@
 #!@SHELL@
-# $Id: gen-pkgconfig.in,v 1.14 2012/01/01 01:48:23 tom Exp $
+# $Id: gen-pkgconfig.in,v 1.15 2013/03/16 23:33:34 tom Exp $
 ##############################################################################
-# Copyright (c) 2009-2010,2011 Free Software Foundation, Inc.                #
+# Copyright (c) 2009-2012,2013 Free Software Foundation, Inc.                #
 #                                                                            #
 # Permission is hereby granted, free of charge, to any person obtaining a    #
 # copy of this software and associated documentation files (the "Software"), #
@@ -39,10 +39,10 @@
 # library, except that the tinfo library does not depend on ncurses.
 LIB_NAME=@LIB_NAME@
 TINFO_NAME=@TINFO_NAME@
-PANEL_NAME=panel # @PANEL_NAME@
-MENU_NAME=menu # @MENU_NAME@
-FORM_NAME=form # @FORM_NAME@
-CXX_NAME=ncurses++ # @CXX_NAME@
+PANEL_NAME=@PANEL_NAME@
+MENU_NAME=@MENU_NAME@
+FORM_NAME=@FORM_NAME@
+CXX_NAME=@CXX_NAME@
 DFT_DEP_SUFFIX=@DFT_DEP_SUFFIX@
 TINFO_ARG_SUFFIX=@TINFO_ARG_SUFFIX@
 CXX_LIB_SUFFIX=@CXX_LIB_SUFFIX@
Index: misc/terminfo.src
--- ncurses-5.9-20130309+/misc/terminfo.src	2012-11-04 15:59:03.000000000 +0000
+++ ncurses-5.9-20130316/misc/terminfo.src	2013-03-16 22:39:31.000000000 +0000
@@ -6,8 +6,8 @@
 # Report bugs and new terminal descriptions to
 #	bug-ncurses@gnu.org
 #
-#	$Revision: 1.470 $
-#	$Date: 2012/11/04 15:59:03 $
+#	$Revision: 1.472 $
+#	$Date: 2013/03/16 22:39:31 $
 #
 # The original header is preserved below for reference.  It is noted that there
 # is a "newer" version which differs in some cosmetic details (but actually
@@ -1025,7 +1025,7 @@
 # you use a 512-character console font. This uses bold for bright
 # foreground colors and blink for bright background colors.
 linux-16color|linux console with 16 colors,
-	colors#16, ncv#54, pairs#256,
+	colors#16, ncv#62, pairs#256,
 	setab=\E[4%p1%{8}%m%d%?%p1%{8}%>%t;5%e%p1%{8}%=%t;2%e;25%;m,
 	setaf=\E[3%p1%{8}%m%d%?%p1%{8}%>%t;1%e%p1%{8}%=%t;2%e;21%;m,
 	use=linux,
@@ -4890,7 +4890,7 @@
 	rs2=\E[r\E[m\E[2J\E[H\E[?7h\E[?1;3;4;6l\E[4l\E>,
 	s0ds=\E(B, s1ds=\E(0, sc=\E7, setab=\E[48;5;%p1%dm,
 	setaf=\E[38;5;%p1%dm,
-	sgr=\E[0%?%p1%p6%|%t;1%;%?%p2%t;4%;%?%p1%p3%|%t;7%;%;m%?%p9%t\E(0%e\E(B%;,
+	sgr=\E[0%?%p1%p6%|%t;1%;%?%p2%t;4%;%?%p1%p3%|%t;7%;m%?%p9%t\E(0%e\E(B%;,
 	sgr0=\E[m\E(B, smacs=\E(0, smcup=\E7\E[?47h, smir=\E[4h,
 	smso=\E[7m, smul=\E[4m, tbc=\E[3g, tsl=\E]2;%p1,
 	vpa=\E[%i%p1%dd,
@@ -5431,13 +5431,13 @@
 # It supports bold, but not underline -TD (2009-09-19)
 sun-color|Sun Microsystems Workstation console with color support (IA systems),
 	colors#8, ncv#3, pairs#64,
-	cub=\E[%p1%dD, cud=\E[%p1%dB, cuf=\E[%p1%dC,
+	bold=\E[1m, cub=\E[%p1%dD, cud=\E[%p1%dB, cuf=\E[%p1%dC,
 	cuu=\E[%p1%dA, home=\E[H, op=\E[0m, rs2=\E[s,
 	setab=\E[4%p1%dm, setaf=\E[3%p1%dm,
 	setb=\E[4%?%p1%{1}%=%t4%e%p1%{3}%=%t6%e%p1%{4}%=%t1%e%p1%{6}%=%t3%e%p1%d%;m,
 	setf=\E[3%?%p1%{1}%=%t4%e%p1%{3}%=%t6%e%p1%{4}%=%t1%e%p1%{6}%=%t3%e%p1%d%;m,
-	sgr=\E[0%?%p1;1%;%?%p3%;7%;m, sgr0=\E[m, smso=\E[1m,
-	use=sun,
+	sgr=\E[0%?%p6%t;1%;%?%p1%p3%|%t;7%;m, sgr0=\E[m,
+	smso=\E[7m, use=sun,
 
 #### Iris consoles
 #
@@ -22960,4 +22960,12 @@
 #	* un-cancel the initc in vte-256color, since this was implemented
 #	  starting with version 0.20 in 2009 -TD
 #
+# 2013-03-16
+#	* correct typo in sgr string for sun-color,
+#	  add bold for consistency with sgr,
+#	  change smso for consistency with sgr -TD
+#	* correct typo in sgr string for terminator -TD
+#	* add blink to the attributes masked by ncv in linux-16color (report
+#	  by Benjamin Sittler)
+#
 ######## SHANTIH!  SHANTIH!  SHANTIH!
Index: mk-1st.awk
Prereq:  1.90 
--- ncurses-5.9-20130309+/mk-1st.awk	2013-03-10 00:09:14.000000000 +0000
+++ ncurses-5.9-20130316/mk-1st.awk	2013-03-12 11:09:40.000000000 +0000
@@ -1,4 +1,4 @@
-# $Id: mk-1st.awk,v 1.90 2013/03/10 00:09:14 tom Exp $
+# $Id: mk-1st.awk,v 1.95 2013/03/12 11:09:40 tom Exp $
 ##############################################################################
 # Copyright (c) 1998-2012,2013 Free Software Foundation, Inc.                #
 #                                                                            #
@@ -130,23 +130,38 @@
 		}
 	}
 function rmlink(directory, dst) {
-		printf "\t-rm -f %s/%s\n", directory, dst
+		if ( dst != "" ) {
+			printf "\t-rm -f %s/%s\n", directory, dst
+		}
 	}
 function removelinks(directory) {
-		rmlink(directory, end_name);
+		nlinks = 0;
+		links[nlinks++] = end_name;
 		if ( DoLinks == "reverse" ) {
 			if ( ShlibVer == "rel" ) {
-				rmlink(directory, abi_name);
-				rmlink(directory, rel_name);
+				links[nlinks++] = abi_name;
+				links[nlinks++] = rel_name;
 			} else if ( ShlibVer == "abi" ) {
-				rmlink(directory, abi_name);
+				links[nlinks++] = abi_name;
 			}
 		} else {
 			if ( ShlibVer == "rel" ) {
-				rmlink(directory, abi_name);
-				rmlink(directory, lib_name);
+				links[nlinks++] = abi_name;
+				links[nlinks++] = lib_name;
 			} else if ( ShlibVer == "abi" ) {
-				rmlink(directory, lib_name);
+				links[nlinks++] = lib_name;
+			}
+		}
+		for (j = 0; j < nlinks; ++j) {
+			found = 0;
+			for (k = 0; k < j; ++k ) {
+				if ( links[j] == links[k] ) {
+					found = 1;
+					break;
+				}
+			}
+			if ( !found ) {
+				rmlink(directory, links[j]);
 			}
 		}
 	}
@@ -234,8 +249,9 @@
 		printf "\t%s %s %s\n", program, src_name, dst_name
 	}
 BEGIN	{
-		found = 0
-		using = 0
+		TOOL_PREFIX = "";
+		found = 0;
+		using = 0;
 	}
 	/^@/ {
 		using = 0
@@ -244,6 +260,15 @@
 		} else if (index(subset,$2) > 0) {
 			if (using == 0) {
 				if (found == 0) {
+					if ( name ~ /^.*\+\+.*/ ) {
+						if ( CXX_MODEL == "NORMAL" && MODEL == "SHARED" ) {
+							print  ""
+							printf "# overriding model from %s to match CXX_MODEL\n", MODEL;
+							MODEL = "NORMAL";
+							suffix = ".a";
+							DoLinks = "no";
+						}
+					}
 					print  ""
 					printf "# generated by mk-1st.awk (subset=%s)\n", subset
 					printf "#  name:          %s\n", name 
@@ -300,11 +325,19 @@
 				printf "%s_OBJS =", OBJS
 				if ( $2 == "lib" ) {
 					found = 1;
-				} else if ( $2 == "c++" && CXX_MODEL == "SHARED" ) {
+				} else if ( $2 == "c++" ) {
+					TOOL_PREFIX = "CXX_";
 					found = 1;
 				} else {
 					found = 2;
 				}
+				if ( $2 == "c++" ) {
+					CC_NAME="CXX"
+					CC_FLAG="CXXFLAGS"
+				} else {
+					CC_NAME="CC"
+					CC_FLAG="CFLAGS"
+				}
 			}
 			printf " \\\n\t../%s/%s$o", model, $1;
 		}
@@ -400,11 +433,6 @@
 			}
 			else if ( MODEL == "LIBTOOL" )
 			{
-				if ( $2 == "c++" ) {
-					compile="CXX"
-				} else {
-					compile="CC"
-				}
 				end_name = lib_name;
 				printf "../lib/%s : $(%s_OBJS)\n", lib_name, OBJS
 				if ( is_ticlib() ) {
@@ -414,7 +442,10 @@
 				} else {
 					which_list = "SHLIB_LIST";
 				}
-				printf "\tcd ../lib && $(LIBTOOL_LINK) $(%s) -o %s $(%s_OBJS:$o=.lo) -rpath $(DESTDIR)$(libdir) %s $(NCURSES_MAJOR):$(NCURSES_MINOR) $(LT_UNDEF) $(%s) $(LDFLAGS)\n", compile, lib_name, OBJS, libtool_version, which_list
+				printf "\tcd ../lib && $(LIBTOOL_LINK) $(%s) $(%s) \\\n", CC_NAME, CC_FLAG;
+				printf "\t\t-o %s $(%s_OBJS:$o=.lo) \\\n", lib_name, OBJS;
+				printf "\t\t-rpath $(DESTDIR)$(libdir) \\\n";
+				printf "\t\t%s $(NCURSES_MAJOR):$(NCURSES_MINOR) $(LT_UNDEF) $(%s) $(LDFLAGS)\n", libtool_version, which_list;
 				print  ""
 				print  "install \\"
 				print  "install.libs \\"
@@ -432,7 +463,7 @@
 			{
 				end_name = lib_name;
 				printf "../lib/%s : $(%s_OBJS)\n", lib_name, OBJS
-				printf "\t$(AR) $(ARFLAGS) $@ $?\n"
+				printf "\t$(%sAR) $(%sARFLAGS) $@ $?\n", TOOL_PREFIX, TOOL_PREFIX;
 				printf "\t$(RANLIB) $@\n"
 				if ( host == "vxworks" )
 				{
Index: ncurses/base/lib_addch.c
Prereq:  1.126 
--- ncurses-5.9-20130309+/ncurses/base/lib_addch.c	2013-03-02 21:06:47.000000000 +0000
+++ ncurses-5.9-20130316/ncurses/base/lib_addch.c	2013-03-17 00:30:29.000000000 +0000
@@ -36,7 +36,7 @@
 #include <curses.priv.h>
 #include <ctype.h>
 
-MODULE_ID("$Id: lib_addch.c,v 1.126 2013/03/02 21:06:47 tom Exp $")
+MODULE_ID("$Id: lib_addch.c,v 1.127 2013/03/17 00:30:29 tom Exp $")
 
 static const NCURSES_CH_T blankchar = NewChar(BLANK_TEXT);
 
@@ -431,7 +431,7 @@
 #if USE_WIDEC_SUPPORT
 	       || ((sp == 0 || !sp->_legacy_coding) &&
 		   (WINDOW_EXT(win, addch_used)
-		    || !_nc_is_charable(t)))
+		    || !_nc_is_charable(CharOf(ch))))
 #endif
 	)) {
 	return waddch_literal(win, ch);
Index: package/debian/changelog
--- ncurses-5.9-20130309+/package/debian/changelog	2013-03-09 16:12:16.000000000 +0000
+++ ncurses-5.9-20130316/package/debian/changelog	2013-03-16 16:00:27.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (5.9-20130309) unstable; urgency=low
+ncurses6 (5.9-20130316) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 09 Mar 2013 11:12:13 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 10 Mar 2013 19:17:14 -0400
 
 ncurses6 (5.9-20120608) unstable; urgency=low
 
Index: package/ncurses.spec
--- ncurses-5.9-20130309+/package/ncurses.spec	2013-03-09 21:50:57.000000000 +0000
+++ ncurses-5.9-20130316/package/ncurses.spec	2013-03-16 16:00:27.000000000 +0000
@@ -1,7 +1,7 @@
 Summary: shared libraries for terminal handling
 Name: ncurses6
 Release: 5.9
-Version: 20130309
+Version: 20130316
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{release}-%{version}.tgz
Index: progs/dump_entry.c
Prereq:  1.104 
--- ncurses-5.9-20130309+/progs/dump_entry.c	2012-12-30 00:51:13.000000000 +0000
+++ ncurses-5.9-20130316/progs/dump_entry.c	2013-03-17 00:27:15.000000000 +0000
@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998-2011,2012 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998-2012,2013 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -39,7 +39,7 @@
 #include "termsort.c"		/* this C file is generated */
 #include <parametrized.h>	/* so is this */
 
-MODULE_ID("$Id: dump_entry.c,v 1.104 2012/12/30 00:51:13 tom Exp $")
+MODULE_ID("$Id: dump_entry.c,v 1.107 2013/03/17 00:27:15 tom Exp $")
 
 #define INDENT			8
 #define DISCARD(string) string = ABSENT_STRING
@@ -491,7 +491,7 @@
 }
 
 static char *
-fmt_complex(char *src, int level)
+fmt_complex(TERMTYPE *tterm, const char *capability, char *src, int level)
 {
     bool percent = FALSE;
     bool params = has_params(src);
@@ -527,13 +527,15 @@
 		    strncpy_DYN(&tmpbuf, "%", 1);
 		    strncpy_DYN(&tmpbuf, src, 1);
 		    if (*src++ == '?') {
-			src = fmt_complex(src, level + 1);
+			src = fmt_complex(tterm, capability, src, level + 1);
 			if (*src != '\0' && *src != '%') {
 			    strncpy_DYN(&tmpbuf, "\n", 1);
 			    indent_DYN(&tmpbuf, level + 1);
 			}
 		    } else if (level == 1) {
-			_nc_warning("%%%c without %%?", *src);
+			_nc_warning("%s: %%%c without %%? in %s",
+				    _nc_first_name(tterm->term_names),
+				    *src, capability);
 		    }
 		}
 		continue;
@@ -547,9 +549,17 @@
 		    indent_DYN(&tmpbuf, level);
 		    strncpy_DYN(&tmpbuf, "%", 1);
 		    strncpy_DYN(&tmpbuf, src++, 1);
+		    if (src[0] == '%'
+			&& src[1] != '\0'
+			&& (strchr("?e;", src[1])) == 0) {
+			tmpbuf.text[tmpbuf.used++] = '\n';
+			indent_DYN(&tmpbuf, level);
+		    }
 		    return src;
 		}
-		_nc_warning("%%; without %%?");
+		_nc_warning("%s: %%; without %%? in %s",
+			    _nc_first_name(tterm->term_names),
+			    capability);
 	    }
 	    break;
 	case 'p':
@@ -820,7 +830,7 @@
 		if (pretty
 		    && (outform == F_TERMINFO
 			|| outform == F_VARIABLE)) {
-		    fmt_complex(src, 1);
+		    fmt_complex(tterm, name, src, 1);
 		} else {
 		    strcpy_DYN(&tmpbuf, src);
 		}
Index: progs/tic.c
Prereq:  1.184 
--- ncurses-5.9-20130309+/progs/tic.c	2013-03-09 23:14:07.000000000 +0000
+++ ncurses-5.9-20130316/progs/tic.c	2013-03-17 00:57:05.000000000 +0000
@@ -46,7 +46,7 @@
 #include <hashed_db.h>
 #include <transform.h>
 
-MODULE_ID("$Id: tic.c,v 1.184 2013/03/09 23:14:07 tom Exp $")
+MODULE_ID("$Id: tic.c,v 1.185 2013/03/17 00:57:05 tom Exp $")
 
 #define STDIN_NAME "<stdin>"
 
@@ -432,7 +432,7 @@
 	 */
 	result = fopen(alt_file, "r+");
 	fclose(target);
-	to_remove = alt_file;
+	to_remove = strdup(alt_file);
     }
     return result;
 }
